==> 74876-qtrans-0.2.1.5.tar.gz: qtrans-0.2.1.5/src/html_widget.h <==
/***************************************************************************
                          html_widget.h  -  description
                             -------------------
    begin                : December 2007
    copyright            : (c) 2007 by Roland Suchan
    email                : vmp@arcor.de
    license              : GPL v 2.0
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This file is part of QTrans.                                          *
 *                                                                         *
 *   QTrans is free software; you can redistribute it and/or modify        *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; version 2 of the License.               *
 *                                                                         *
 *   QTrans is distributed in the hope that it will be useful,             *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with QTrans. If not, see <http://www.gnu.org/licenses/> or      *
 *   write to the Free Software Foundation, Inc.,                          *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.         *
 *                                                                         *
 ***************************************************************************/

#ifndef HTML_WIDGET_H
#define HTML_WIDGET_H

//#include <khtml_part.h>
#include <KMenu>
#include <KAction>
#include <QMessageBox>

#include <QWebView>	//ooo
#include <QContextMenuEvent>	//ooo
#include <KMessageBox>		//ooo
#include <QVBoxLayout>		//ooo
#include <QHBoxLayout>		//ooo
#include <QLineEdit>		//ooo
#include <QLabel>		//ooo
#include <QPushButton>		//ooo
#include <QAction>		//ooo
#include <QMenu>		//ooo
//#include "qtrans.h"	//ooo

//class QTrans;

//class Html_Widget : public KHTMLPart  {
class Html_Widget : public QWebView  {	//ooo
	Q_OBJECT
public:
	//Html_Widget(QWidget *parentWidget=0, const char *widgetname=0,QObject *parent=0,
	//					const char *name=0,GUIProfile prof=DefaultGUI);
	//Html_Widget(QWidget *parentWidget=0, QObject *parent=0, GUIProfile prof=DefaultGUI);
	Html_Widget(QWidget *parent = 0);	//ooo
	//~Html_Widget();
	~Html_Widget();	//ooo

	void clear();
	void setOut(QString);
	void setFont(QString,int,QString);
	void buildMenu();
	QString bgColor, txtColor;
	QString expressionTxtColor;	//ooo
	QString sentencePartTxtColor;	//ooo
	//KPopupMenu *popMenu;   //ooo_

	QMenu *languageMenu;	//ooo
	KMenu *popMenu;   //ooo
	QActionGroup *languageGroup;   //ooo
	QList<QAction*> actionsList;	//ooo
	QWidget *Par;	//ooo
	QAction *findAct;	//ooo
	QMenu *menu;		//ooo

public slots:
	//void slot_PopupMenu(const QString& , const QPoint &);
	void slot_PopupMenu(QAction *);
	void slot_findMenu();

private:
	QString fontName,Charset;
	int Size;
	//QWidget *Par;
        //webPage *m_page;

protected:
	void contextMenuEvent(QContextMenuEvent *event);	//ooo
	//void mousePressEvent(QMouseEvent *event);	//ooo

};


class FindWidget : public QWidget
{
	 Q_OBJECT
public:
	FindWidget(Html_Widget *parent=0);
	~FindWidget();

	Html_Widget *Par2;

	QVBoxLayout *mainLayout;
	QHBoxLayout *Box1;
	QLabel *Label1;
	QLineEdit *wordName;

	QHBoxLayout *Box4;
	QPushButton *bOk;
	QPushButton *bCancel;

public slots:
	void slot_Close();
	void slot_Ok();
};

#endif

==> 74876-qtrans-0.2.1.10-4.tar.gz: qtrans-0.2.1.10-4/src/html_widget.h <==
/***************************************************************************
                          html_widget.h  -  description
                             -------------------
    begin                : December 2007
    copyright            : (c) 2007 by Roland Suchan
    email                : vmp@arcor.de
    license              : GPL v 2.0
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This file is part of QTrans.                                          *
 *                                                                         *
 *   QTrans is free software; you can redistribute it and/or modify        *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; version 2 of the License.               *
 *                                                                         *
 *   QTrans is distributed in the hope that it will be useful,             *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with QTrans. If not, see <http://www.gnu.org/licenses/> or      *
 *   write to the Free Software Foundation, Inc.,                          *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.         *
 *                                                                         *
 ***************************************************************************/

#ifndef HTML_WIDGET_H
#define HTML_WIDGET_H

//#include <khtml_part.h>
#include <KMenu>
#include <KAction>
#include <QMessageBox>

#include <QWebView>		//ooo
#include <QContextMenuEvent>	//ooo
#include <KMessageBox>		//ooo
#include <QVBoxLayout>		//ooo
#include <QHBoxLayout>		//ooo
#include <QLineEdit>		//ooo
#include <QLabel>		//ooo
#include <QPushButton>		//ooo
#include <QAction>		//ooo
#include <QMenu>		//ooo

//#include "qtrans.h"	//ooo

//class QTrans;

//class Html_Widget : public KHTMLPart  {
class Html_Widget : public QWebView  {	//ooo
	Q_OBJECT
public:
	//Html_Widget(QWidget *parentWidget=0, const char *widgetname=0,QObject *parent=0,
	//					const char *name=0,GUIProfile prof=DefaultGUI);
	//Html_Widget(QWidget *parentWidget=0, QObject *parent=0, GUIProfile prof=DefaultGUI);
	Html_Widget(QWidget *parent = 0);	//ooo
	//~Html_Widget();
	~Html_Widget();	//ooo

	void clear();
	void setOut(QString);
	//void setFont(QString,int,QString);
	void setFont(QString,int,QFont::Style,int,QString);	//ooo
	void buildMenu();
	QString bgColor, txtColor;
	QString expressionTxtColor;	//ooo
	QString sentencePartTxtColor;	//ooo
	//KPopupMenu *popMenu;   //ooo_

	QMenu *languageMenu;	//ooo
	KMenu *popMenu;   //ooo
	QActionGroup *languageGroup;   //ooo
	QList<QAction*> actionsList;	//ooo
	QWidget *Par;	//ooo
	QAction *findAct;	//ooo
	QMenu *menu;		//ooo

public slots:
	//void slot_PopupMenu(const QString& , const QPoint &);
	void slot_PopupMenu(QAction *);
	void slot_findMenu();

private:
	QString fontName,Charset;
	QString fontStyle;		//ooo
	QString fontWeight;			//ooo
	int Size;
	//QWidget *Par;
        //webPage *m_page;

protected:
	void contextMenuEvent(QContextMenuEvent *event);	//ooo
	//void mousePressEvent(QMouseEvent *event);	//ooo

};


class FindWidget : public QWidget
{
	 Q_OBJECT
public:
	FindWidget(Html_Widget *parent=0);
	~FindWidget();

	Html_Widget *Par2;

	QVBoxLayout *mainLayout;
	QHBoxLayout *Box1;
	QLabel *Label1;
	QLineEdit *wordName;

	QHBoxLayout *Box4;
	QPushButton *bOk;
	QPushButton *bCancel;

public slots:
	void slot_Close();
	void slot_Ok();
};

#endif
